Package: RFLOMICS
Title: Interactive web application for Omics-data analysis
Version: 1.5.0
Authors@R: 
    c(
    person(given = "Nadia", family = "Bessoltane",
        email = "nadia.bessoltane@inrae.fr", role = c("aut", "cre"), 
        comment = c(ORCID="0000-0001-6931-2529")),
    person(given = "Delphine", family = "Charif", 
        email = "delphine.charif@inrae.fr", role = c("aut"), 
        comment = c(ORCID="0000-0002-1949-5969")),
    person(given = "Audrey", family = "Hulot", 
        email = "audrey.hulot@inrae.fr", role = c("aut"), 
        comment = c(ORCID = "0000-0002-9647-6470")),
    person(given = "Christine", family = "Paysant-Leroux",
        email = "christine.paysant-le-roux@inrae.fr", role = c("aut"), 
        comment = c(ORCID = "0000-0003-2046-6492")),
    person(given = "Gwendal", family = "Cueff",
        email = "gwendal.cueff@inrae.fr", role = c("aut"))
    )
Description: R-package with shiny interface, provides a framework for 
    the analysis of transcriptomics, proteomics and/or metabolomics data. 
    The interface offers a guided experience for the user, from the definition
    of the experimental design to the integration of several omics table together.
    A report can be generated with all settings and analysis results.
URL: https://github.com/RFLOMICS/RFLOMICS
BugReports: https://github.com/RFLOMICS/RFLOMICS/issues
Depends: R (>= 4.4.0), SummarizedExperiment, MultiAssayExperiment,
        shinyBS, dplyr, ggplot2, htmltools, knitr, coseq
biocViews: ShinyApps, DifferentialExpression, Metabolomics, Proteomics,
        Transcriptomics
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: testthat, shinytest2, BiocStyle, org.Hs.eg.db
VignetteBuilder: knitr
Imports: vroom, org.At.tair.db, AnnotationDbi, clusterProfiler,
        ComplexHeatmap, data.table, DT, edgeR, FactoMineR, ggpubr,
        ggnetwork, ggrepel, grDevices, grid, httr, limma, magrittr,
        methods, mixOmics, MOFA2, plotly, purrr, RColorBrewer,
        reshape2, reticulate, rmarkdown, S4Vectors, shiny,
        shinydashboard, shinyWidgets, stats, stringr, tidyr, tibble,
        tidyselect, UpSetR,
SystemRequirements: Python (>=3), numpy, pandas, h5py, scipy, argparse,
        sklearn, mofapy2 (>=0.7.1)
git_url: https://git.bioconductor.org/packages/RFLOMICS
git_branch: devel
git_last_commit: f2a9e77
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:12:42 UTC; biocbuild
Author: Nadia Bessoltane [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6931-2529>),
  Delphine Charif [aut] (ORCID: <https://orcid.org/0000-0002-1949-5969>),
  Audrey Hulot [aut] (ORCID: <https://orcid.org/0000-0002-9647-6470>),
  Christine Paysant-Leroux [aut] (ORCID:
    <https://orcid.org/0000-0003-2046-6492>),
  Gwendal Cueff [aut]
Maintainer: Nadia Bessoltane <nadia.bessoltane@inrae.fr>
Built: R 4.6.0; ; 2026-05-19 05:05:33 UTC; unix
