# Generated by roxygen2: do not edit by hand

export(createRflomicsMAE)
export(runRFLOMICS)
exportClasses(RflomicsMAE)
exportClasses(RflomicsSE)
exportMethods(checkExpDesignCompleteness)
exportMethods(filterDiffAnalysis)
exportMethods(generateExpressionContrast)
exportMethods(generateModelFormulae)
exportMethods(generateReport)
exportMethods(getAnalysis)
exportMethods(getAnalyzedDatasetNames)
exportMethods(getAnnotAnalysesSummary)
exportMethods(getBatchFactors)
exportMethods(getBioFactors)
exportMethods(getCoExpAnalysesSummary)
exportMethods(getCoeffNorm)
exportMethods(getCoexpClusters)
exportMethods(getCoexpSettings)
exportMethods(getDEList)
exportMethods(getDEMatrix)
exportMethods(getDatasetNames)
exportMethods(getDesignMat)
exportMethods(getDiffAnalysesSummary)
exportMethods(getDiffSettings)
exportMethods(getDiffStat)
exportMethods(getEnrichRes)
exportMethods(getEnrichSettings)
exportMethods(getFactorModalities)
exportMethods(getFactorNames)
exportMethods(getFactorTypes)
exportMethods(getFilterSettings)
exportMethods(getFilteredFeatures)
exportMethods(getImputSettings)
exportMethods(getMOFA)
exportMethods(getMOFASettings)
exportMethods(getMetaFactors)
exportMethods(getMixOmics)
exportMethods(getMixOmicsSettings)
exportMethods(getModelFormula)
exportMethods(getNormSettings)
exportMethods(getOmicsTypes)
exportMethods(getProcessedData)
exportMethods(getProjectName)
exportMethods(getRflomicsSE)
exportMethods(getSelectedContrasts)
exportMethods(getSelectedSamples)
exportMethods(getTransSettings)
exportMethods(getValidContrasts)
exportMethods(isProcessedData)
exportMethods(plotBoxplotDE)
exportMethods(plotClusterProfiler)
exportMethods(plotCoExpression)
exportMethods(plotCoExpressionProfile)
exportMethods(plotConditionsOverview)
exportMethods(plotCoseqContrasts)
exportMethods(plotDataDistribution)
exportMethods(plotDataOverview)
exportMethods(plotDiffAnalysis)
exportMethods(plotEnrichComp)
exportMethods(plotExpDesignCompleteness)
exportMethods(plotHeatmapDesign)
exportMethods(plotLibrarySize)
exportMethods(plotMissingValues)
exportMethods(plotOmicsPCA)
exportMethods(prepareForIntegration)
exportMethods(rflomicsMAE2MAE)
exportMethods(runAnnotationEnrichment)
exportMethods(runCoExpression)
exportMethods(runDataProcessing)
exportMethods(runDiffAnalysis)
exportMethods(runFeatureFiltering)
exportMethods(runMVImputation)
exportMethods(runNormalization)
exportMethods(runOmicsIntegration)
exportMethods(runOmicsPCA)
exportMethods(runSampleFiltering)
exportMethods(runTransformData)
exportMethods(setMOFA)
exportMethods(setMixOmics)
exportMethods(setModelFormula)
exportMethods(setSelectedContrasts)
exportMethods(setValidContrasts)
exportMethods(subRflomicsMAE)
exportMethods(sumMixOmics)
exportMethods(sumORA)
import(coseq)
import(ggplot2)
import(htmltools)
import(knitr)
import(methods)
import(shiny, except = renderDataTable)
importClassesFrom(ComplexHeatmap,Heatmap)
importClassesFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(AnnotationDbi,keytypes)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(ComplexHeatmap,draw)
importFrom(DT,JS)
importFrom(DT,datatable)
importFrom(DT,formatSignif)
importFrom(DT,formatStyle)
importFrom(DT,renderDataTable)
importFrom(DT,styleEqual)
importFrom(DT,styleInterval)
importFrom(FactoMineR,PCA)
importFrom(FactoMineR,coord.ellipse)
importFrom(MOFA2,create_mofa)
importFrom(MOFA2,get_default_data_options)
importFrom(MOFA2,get_default_model_options)
importFrom(MOFA2,get_default_training_options)
importFrom(MOFA2,get_dimensions)
importFrom(MOFA2,get_factors)
importFrom(MOFA2,get_weights)
importFrom(MOFA2,plot_data_heatmap)
importFrom(MOFA2,plot_data_overview)
importFrom(MOFA2,plot_factor)
importFrom(MOFA2,plot_factor_cor)
importFrom(MOFA2,plot_variance_explained)
importFrom(MOFA2,plot_weights)
importFrom(MOFA2,prepare_mofa)
importFrom(MOFA2,run_mofa)
importFrom(MOFA2,views_names)
importFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(MultiAssayExperiment,listToMap)
importFrom(RColorBrewer,brewer.pal)
importFrom(RColorBrewer,brewer.pal.info)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,SimpleList)
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(UpSetR,upset)
importFrom(clusterProfiler,bitr)
importFrom(clusterProfiler,enrichGO)
importFrom(clusterProfiler,enrichKEGG)
importFrom(clusterProfiler,enricher)
importFrom(clusterProfiler,setReadable)
importFrom(data.table,data.table)
importFrom(data.table,fread)
importFrom(data.table,setDT)
importFrom(data.table,setcolorder)
importFrom(data.table,setnames)
importFrom(dplyr,count)
importFrom(dplyr,group_by_at)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(edgeR,DGEList)
importFrom(edgeR,calcNormFactors)
importFrom(edgeR,cpm)
importFrom(edgeR,estimateDisp)
importFrom(edgeR,filterByExpr)
importFrom(edgeR,glmFit)
importFrom(edgeR,glmLRT)
importFrom(edgeR,topTags)
importFrom(ggnetwork,geom_edges)
importFrom(ggnetwork,geom_nodes)
importFrom(ggnetwork,ggnetwork)
importFrom(ggnetwork,theme_blank)
importFrom(ggpubr,ggarrange)
importFrom(ggpubr,ggmaplot)
importFrom(ggrepel,geom_label_repel)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grid,gpar)
importFrom(grid,grid.draw)
importFrom(grid,unit)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,removeBatchEffect)
importFrom(limma,topTable)
importFrom(limma,voom)
importFrom(magrittr,"%>%")
importFrom(mixOmics,block.plsda)
importFrom(mixOmics,block.splsda)
importFrom(mixOmics,cimDiablo)
importFrom(mixOmics,network)
importFrom(mixOmics,plotIndiv)
importFrom(mixOmics,plotLoadings)
importFrom(mixOmics,plotVar)
importFrom(mixOmics,plsda)
importFrom(mixOmics,splsda)
importFrom(mixOmics,tune.block.splsda)
importFrom(mixOmics,tune.splsda)
importFrom(mixOmics,unmap)
importFrom(plotly,ggplotly)
importFrom(plotly,plotlyOutput)
importFrom(plotly,renderPlotly)
importFrom(purrr,reduce)
importFrom(reshape2,dcast)
importFrom(reshape2,melt)
importFrom(reshape2,recast)
importFrom(rmarkdown,render)
importFrom(shinyBS,addPopover)
importFrom(shinyBS,bsButton)
importFrom(shinyBS,bsTooltip)
importFrom(shinyBS,popify)
importFrom(shinyWidgets,materialSwitch)
importFrom(shinyWidgets,pickerInput)
importFrom(shinydashboard,box)
importFrom(shinydashboard,dashboardBody)
importFrom(shinydashboard,dashboardHeader)
importFrom(shinydashboard,dashboardPage)
importFrom(shinydashboard,dashboardSidebar)
importFrom(shinydashboard,menuItem)
importFrom(shinydashboard,menuItemOutput)
importFrom(shinydashboard,menuSubItem)
importFrom(shinydashboard,renderMenu)
importFrom(shinydashboard,sidebarMenu)
importFrom(shinydashboard,tabBox)
importFrom(shinydashboard,tabItem)
importFrom(shinydashboard,tabItems)
importFrom(shinydashboard,updateTabItems)
importFrom(stats,as.formula)
importFrom(stats,dist)
importFrom(stats,formula)
importFrom(stats,hclust)
importFrom(stats,kruskal.test)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,terms.formula)
importFrom(stats,update)
importFrom(stringr,fixed)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_length)
importFrom(stringr,str_remove)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_subset)
importFrom(stringr,str_wrap)
importFrom(tibble,column_to_rownames)
importFrom(tibble,rownames_to_column)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(tidyselect,all_of)
importFrom(tidyselect,any_of)
importFrom(tidyselect,starts_with)
importFrom(tidyselect,where)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
importFrom(vroom,vroom)
importMethodsFrom(ComplexHeatmap,draw)
