---
editor_options: 
  markdown: 
    wrap: 72
---

<br>

## `r paste0("6.", num, " ", data)` {.tabset .tabset-fade .tabset-pills}

* **Methods:**

The The **Overrepresentation analysis (ORA)** was performed using the version 
(`r RFLOMICS:::.getPackageInfo(rflomics.MAE, "clusterProfiler")`) of **clusterProfiler** R-package,
based on following databases:


```{r, results ='asis'}

dataset.SE <- getRflomicsSE(rflomics.MAE, data)
variableName   <- RFLOMICS:::.omicsDic(dataset.SE)[["variableName"]]
validContrasts <- getValidContrasts(dataset.SE)

out <- NULL
for (ontology in names(annot.list[[data]])){
  
  out <- c(out, knit_child(paste0(
    path.package("RFLOMICS"),"/RFLOMICSapp/",
    "report_06_enrichmentORA_per_database.Rmd"), quiet=TRUE))
}
asis_output(out)

```
